<?php

if (!function_exists('ejobsitesoftware_theme_support')) {
    function ejobsitesoftware_theme_support()
    {
        // Adds dynamic title tag support
        add_theme_support('title-tag');

        /*
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */

        add_theme_support('custom-logo');

        // Custom background color.
        add_theme_support('custom-background');

        // Add support for Block Styles.
        add_theme_support('wp-block-styles');

        // Add support for full and wide align images.
        add_theme_support('align-wide');

        // Add support for editor styles.
        add_theme_support('editor-styles');
        /**
         * Add default posts and comments RSS feed links to <head>.
         */
        add_theme_support('automatic-feed-links');


        add_theme_support('custom-header');

        /**
         * Add post-formats support.
         */
        add_theme_support(
            'post-formats',
            array(
                'link',
                'aside',
                'gallery',
                'image',
                'quote',
                'status',
                'video',
                'audio',
                'chat',
            )
        );

        /*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(1568, 9999);

        add_theme_support("responsive-embeds");

        /*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
             */
        add_theme_support('html5');

        // Add support for responsive embedded content.
        add_theme_support('responsive-embeds');

        $editor_stylesheet_path = './assets/css/style-editor.css';

        // Note, the is_IE global variable is defined by WordPress and is used
        // to detect if the current browser is internet explorer.
        global $is_IE;
        if ($is_IE) {
            $editor_stylesheet_path = './assets/css/ie-editor.css';
        }

        // Enqueue editor styles.
        add_editor_style($editor_stylesheet_path);
    }
}

add_action('after_setup_theme', 'ejobsitesoftware_theme_support');


function ejobsitesoftware_menus()
{
    $locations = array(
        'primary' => "Header Menu",
        'footer' => "Footer Menu"
    );

    register_nav_menus($locations);
}

add_action('init', 'ejobsitesoftware_menus');


function ejobsitesoftware_register_styles()
{

    $version = wp_get_theme()->get('Version');
    wp_enqueue_style('ejobsitesoftware-bootstrap',  get_template_directory_uri() . "/assets/css/bootstrap.min.css");
    wp_enqueue_style('ejobsitesoftware-style', get_template_directory_uri() . "/style.css", array('ejobsitesoftware-bootstrap'), $version, 'all');
    wp_enqueue_style('ejobsitesoftware-fontawesome', get_template_directory_uri() . "/assets/css/all.min.css");
}

add_action('wp_enqueue_scripts', 'ejobsitesoftware_register_styles');

function enqueue_load_fa()
{
    wp_enqueue_style('load-fa', 'https://use.fontawesome.com/releases/v5.5.0/css/all.css');
}

add_action('wp_enqueue_scripts', 'enqueue_load_fa');

function ejobsitesoftware_register_scripts()
{
    wp_enqueue_script('ejobsitesoftware-jquery', get_template_directory_uri() . "/assets/js/jquery-3.4.1.slim.min.js", array(), '3.4.1', true);

    wp_enqueue_script('ejobsitesoftware-popper', get_template_directory_uri() . "/assets/js/popper.min.js", array(), '1.0', true);

    wp_enqueue_script('ejobsitesoftware-bootstrap', get_template_directory_uri() . "/assets/js/bootstrap.min.js", array(), '4.4.1', true);

    wp_enqueue_script('ejobsitesoftware-main', get_template_directory_uri() . "/assets/js/main.js", array(), '1.0', true);
}

add_action('wp_enqueue_scripts', 'ejobsitesoftware_register_scripts');

function ejobsitesoftware_widget_areas()
{

    register_sidebar(
        array(
            'before_title' => '',
            'after_title' => '',
            'before_widget' => '<ul class="social-list list-inline mx-auto">',
            'after_widget' => '</ul>',
            'name' => 'Footer Social Icons',
            'id' => 'footer-1',
            'description' => 'Footer Widget Area'
        )
    );
}

add_action('widgets_init', 'ejobsitesoftware_widget_areas');

function ejobsitesoftware_custom_header_setup()
{
    $args = array(
        'default-image'      => get_template_directory_uri() . '/images/logo.png',
        'header-text'           => false,
        'default-text-color' => '000',
        'width'              => 202,
        'height'             => 50,
        'flex-width'         => true,
        'flex-height'        => true,
    );
    add_theme_support('custom-header', $args);
}

add_action('after_setup_theme', 'ejobsitesoftware_custom_header_setup');

function ejobsitesoftware_custom_logo_setup()
{
    $logo_height = 202;
    $logo_width  = 50;

    $defaults = array(
        'height'               => $logo_height,
        'width'                => $logo_width,
        'flex-height'          => true,
        'flex-width'           => true,
        'header-text'          => array('site-title', 'site-description'),
        'unlink-homepage-logo' => true,
    );

    add_theme_support('custom-logo', $defaults);
}

add_action('after_setup_theme', 'ejobsitesoftware_custom_logo_setup');

function ejobsitesoftware_custom_background_setup()
{
    $defaults = array(
        'default-image'          => '',
        'default-preset'         => 'default', // 'default', 'fill', 'fit', 'repeat', 'custom'
        'default-position-x'     => 'left',    // 'left', 'center', 'right'
        'default-position-y'     => 'top',     // 'top', 'center', 'bottom'
        'default-size'           => 'auto',    // 'auto', 'contain', 'cover'
        'default-repeat'         => 'repeat',  // 'repeat-x', 'repeat-y', 'repeat', 'no-repeat'
        'default-attachment'     => 'scroll',  // 'scroll', 'fixed'
        'default-color'          => '',
        'wp-head-callback'       => '_custom_background_cb',
        'admin-head-callback'    => '',
        'admin-preview-callback' => '',
    );

    add_theme_support('custom-background', $defaults);
}

add_action('after_setup_theme', 'ejobsitesoftware_custom_background_setup');

function ejobsitesoftware_html5_setup()
{
    $defaults = array(
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
        'style',
        'script',
        'navigation-widgets',
    );

    add_theme_support('html5', $defaults);
}
add_action('after_setup_theme', 'ejobsitesoftware_html5_setup');
//for custom logo
add_theme_support( 'custom-logo' );
// TGM Plugin Activation
require_once get_template_directory().'/inc/class-tgm-plugin-activation.php';
require get_template_directory().'/inc/install-plugins.php';




function dm_display_wpjm_categories () {
 	 $terms = get_terms( array(
    'taxonomy' => 'job_listing_category',
    'hide_empty' => false,
) );
  
if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
    echo '<ul>';
    foreach ( $terms as $term ) {
        echo '<li>' . '<a href="' . esc_url( get_term_link( $term ) ) . '">' . $term->name . '</a></li>';
    }
    echo '</ul>';
}
}

add_shortcode('list_categories', 'dm_display_wpjm_categories');
